@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::ARF::Report;
 {
-  $Email::ARF::Report::VERSION = '0.007';
+  $Email::ARF::Report::VERSION = '0.008';
 }
 # ABSTRACT: interpret Abuse Reporting Format (ARF) messages
 
@@ -170,9 +170,6 @@ sub feedback_type { $_[0]->field('Feedback-Type'); }
 sub user_agent    { $_[0]->field('User-Agent');    }
 sub arf_version   { $_[0]->field('Version');       }
 
-
-1;
-
 __END__
 
 =pod
@@ -183,7 +180,7 @@ Email::ARF::Report - interpret Abuse Reporting Format (ARF) messages
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 WARNING
 
@@ -292,13 +289,9 @@ to avoid confusion with the universal C<VERSION> method.
 
 L<http://www.mipassoc.org/arf/>
 
-L<http://www.shaftek.org/publications/drafts/abuse-report/draft-shafranovich-feedback-report-01.txt>
+L<RFC 5965|http://tools.ietf.org/html/rfc5965>
 
-=head1 PERL EMAIL PROJECT
-
-This module is maintained by the Perl Email Project
-
-L<http://emailproject.perl.org/wiki/Email::ARF::Report>
+1;
 
 =head1 AUTHOR
 
